@@ -1,19 +1,18 @@
 ;;;			    mew-refile.el
 ;;;
-;;; Copyright (C) 1994, 1994, and 1996  Yoshinari NOMURA & Kazuhiko YAMAMOTO
+;;;    Copyright (C) 1994-1997  Yoshinari NOMURA & Kazuhiko YAMAMOTO
 ;;;
 ;;;		   This emacs lisp library confirms
 ;;;		GNU GENERAL PUBLIC LICENSE Version 2.
 ;;;
 ;;; Author:  Yoshinari NOMURA <nom@csce.kyushu-u.ac.jp>
 ;;;          Kazuhiko Yamamoto <kazu@is.aist-nara.ac.jp>
-;;; Created: June     11, 1994
-;;; Revised: March     6, 1996
+;;; Created: June  11, 1994
+;;; Revised: March 23, 1997
 ;;;
 
-(defconst mew-refile-version "mew-refile.el version 0.31")
+(defconst mew-refile-version "mew-refile.el version 0.37")
 
-(provide 'mew-refile)
 (require 'mew)
 
 (defvar mew-auto-folder-alist nil
@@ -50,6 +49,14 @@ The format is like this:
 
 (defvar mew-apply-before-refile-function (function downcase))
 
+(defun mew-header-get-addr (string)
+  "Return extracted email address from STRING.
+If STRING is nil, return \" \""
+  (if (null string) 
+      " "
+    (mew-header-extract-addr 
+     (mew-header-syntax string))))
+
 ;;
 ;; mew-summary-refile
 ;;
@@ -58,11 +65,11 @@ The format is like this:
   (if (eobp) 
       (message "No message")
     (let (msg-buffer 
-	  msg hit learn-info tofolder tofolder-list todir mark tmp
+	  msg hit learn-info tofolder tofolder-list todir mark
 	  (first t)
 	  (doit nil)
-	  (mew-analysis mew-summary-buffer-disp-msg))
-      (cond 
+	  (mew-analysis t))
+      (cond
        ((mew-summary-part-number)
 	(re-search-backward mew-summary-message-regex nil t nil)
 	(mew-summary-display))
@@ -139,8 +146,8 @@ The format is like this:
 	(setq mew-summary-refile-last-destination 
 	      (car (cdr (assoc msg mew-summary-buffer-refile))))
 	; XXX: learning should be here !!
-	(mew-summary-multipart-delete)
-	(if (not mark) (mew-summary-display-next))
+	(mew-decode-syntax-delete)
+	(if (and (not mark) (not first)) (mew-summary-display-next))
 	) ; if null doit
       (set-buffer-modified-p nil)
       )))
@@ -242,7 +249,7 @@ The format is like this:
 	(field-contents))
 
     (if (and (stringp field)
-	     (setq field-contents (mew-field-get-value field)))
+	     (setq field-contents (mew-header-get-value field)))
 	(catch 'match
 	  (car 
 	   (mapcar 
@@ -291,8 +298,7 @@ The format is like this:
 (defun mew-guess-by-folder ()
   (let ((to-cc (mew-header-user-collect '("To:" "Cc:" "Apparently-To:")
 					mew-apply-before-refile-function))
-	(ret nil)
-	(from nil))
+	(ret nil))
     (catch 'to-cc-guess
       (while to-cc
 	(if (setq ret (or (cdr (assoc (car to-cc) mew-refile-alist))
@@ -308,8 +314,8 @@ The format is like this:
 ;;
 ;; return: (folder 'mew-guess-by-message-id)
 (defun mew-guess-by-message-id ()
-  (let ((str (or (mew-field-get-value "References:")
-		 (mew-field-get-value "In-Reply-To:"))))
+  (let ((str (or (mew-header-get-value "References:")
+		 (mew-header-get-value "In-Reply-To:"))))
     ; load message id alist
     (if (not mew-msg-id-alist)
 	(setq mew-msg-id-alist
@@ -325,7 +331,7 @@ The format is like this:
 
 
 (defun mew-guess-by-message-id-learn (result)
-  (let ((str (mew-field-get-value "Message-Id:")))
+  (let ((str (mew-header-get-value "Message-Id:")))
     (if (and str (string-match "<[^ \n]*>" str) (car result))
 	(progn 
 	  (setq str 
@@ -348,14 +354,10 @@ The format is like this:
 ;;
 ;; return: (folder 'mew-guess-by-from)
 (defun mew-guess-by-from ()
-  (let ((from (mew-header-delete-ws
-	       (mew-header-extract-addr 
-		(or (mew-field-get-value "From:") " "))))
-	(tocc (mew-header-delete-ws
-	       (mew-header-extract-addr
-		(or (mew-field-get-value "To:")
-		    (mew-field-get-value "Apparently-To:")
-		    " "))))
+  (let ((from (mew-header-get-addr (mew-header-get-value "From:")))
+	(tocc (mew-header-get-addr
+	       (or (mew-header-get-value "To:")
+		   (mew-header-get-value "Apparently-To:"))))
 	(myaddr (mew-header-delete-at mew-mail-address))
 	(folder nil))
     (if (equal myaddr (mew-header-delete-at from))
@@ -370,15 +372,12 @@ The format is like this:
       (list nil 'mew-guess-by-from))
     ))
 
-
 ; result: (user-chosen-folder 'mew-guess-by-from &optoinal from)
 (defun mew-guess-by-from-learn (result)
   (let ((folder (nth 0 result))
 	(id     (nth 1 result))
 	(from   (or (nth 2 result)
-		    (mew-header-delete-ws
-		     (mew-header-extract-addr
-		     (or (mew-field-get-value "From:") " "))))))
+		    (mew-header-get-addr (mew-header-get-value "From:")))))
     (if (and (or (equal id 'mew-guess-by-from)
 		 (equal id 'mew-guess-by-default)
 		 (equal id 'mew-guess-by-message-id))
@@ -404,25 +403,20 @@ The format is like this:
 ;;
 (defun mew-guess-by-default ()
    ;not found in alist .. return default
-  (let ((from (mew-header-delete-ws
-	       (mew-header-extract-addr 
-	       (or (mew-field-get-value "From:") " "))))
-	(tocc (mew-header-delete-ws
-	       (mew-header-extract-addr
-	       (or (mew-field-get-value "To:") 
-		   (mew-field-get-value "Apparently-To:")
-		   " "))))
+  (let ((from (mew-header-get-addr (mew-header-get-value "From:")))
+	(tocc (mew-header-get-addr 
+	       (or (mew-header-get-value "To:") 
+		   (mew-header-get-value "Apparently-To:"))))
 	(myaddr (mew-header-delete-at mew-mail-address)))
     (if (equal myaddr (mew-header-delete-at from))
 	(setq from tocc))
-    (if (mew-member 
-	 (concat mew-folders-default-folder "/")
-	 mew-folder-list)
+    (if (mew-member (concat mew-folders-default-folder "/") mew-folder-list)
 	(list (concat "+" mew-folders-default-folder "/" 
 		      (mew-header-delete-at from))
 	      'mew-guess-by-default from)
       (list (concat "+" (mew-header-delete-at from))
-	    'mew-guess-by-default from))))
+	    'mew-guess-by-default from))
+    ))
 
 ;;
 ;; common routines
@@ -449,7 +443,7 @@ The format is like this:
 ;	  ()
 ;	(find-file-read-only fullname)
 ;	(setq alist 
-;	      (condition-case err
+;	      (condition-case nil
 ;		  (read (current-buffer)) (error nil nil))
 ;	      alist
 ;	      (reverse
@@ -464,11 +458,13 @@ The format is like this:
     (save-excursion
       (if (not (file-readable-p fullname))
 	  ()
-	(find-file-read-only fullname)
+	(set-buffer (get-buffer-create mew-buffer-tmp))
+	(erase-buffer)
+;;;;	(find-file-read-only fullname) ;; this causes hilight!!
+	(insert-file-contents fullname)
 	(setq alist 
-	      (condition-case err
+	      (condition-case nil
 		  (read (current-buffer)) (error nil nil)))
-	(kill-buffer (current-buffer))
 	alist))))
 
 ;(defun mew-alist-save (filename alist)
@@ -522,7 +518,7 @@ The format is like this:
   (if (listp str-list)
       (and str-list
 	   (substring 
-	    (apply 'concat
+	    (apply (function concat)
 		   (mapcar 
 		    (function (lambda (arg)
 				(concat ", " arg)))
@@ -530,3 +526,4 @@ The format is like this:
 	    2))
     str-list))
 
+(provide 'mew-refile)
